/*!
 * \file main.cpp
 * \brief Location of the #main-function. Reads QSettings object from `ThinkPink.ini` and resets unique_ptr.
 */

#include "mainwindow.hpp"

#include <QApplication>
#include <QDir>
#include <QSettings>
#include <QStandardPaths>

std::unique_ptr<QSettings> settings;

/*!
 * \file main.cpp
 */

/*!
 * \brief Reads game settings from `ThinkPink.ini` config file
 * \ingroup Settings_src
 */
void initialise_settings() {
    QString config_filename = "ThinkPink.ini";
    QString config_path = "";

    QString prio_path = QDir(QCoreApplication::applicationDirPath()).filePath(config_filename);
    if (QFileInfo::exists(prio_path)) {
        config_path = prio_path;
    }
    else {
        QList<QStandardPaths::StandardLocation> locations{ QStandardPaths::ConfigLocation, QStandardPaths::AppConfigLocation};
        for (long long i = 0; i < locations.size(); i++) {
            config_path = QStandardPaths::locate( locations.value(i), config_filename);
            if (config_path != "")
                break;
        }
    }

    settings.reset( new QSettings( config_path, QSettings::IniFormat ) );
}

/*!
 * \brief Sets up the #QApplication, then calls #initialise_settings and finally starts the #MainWindow.
 */
int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    initialise_settings();
    MainWindow w;
    w.show();
    return a.exec();
}
