/*!
 * \file samegame.cpp
 * \brief Implementation of the #SameGame class.
 */

#include "samegame.hpp"

void SameGame::initialiseGameMatrix(int rows, int columns) {
    gameMatrix = std::vector<std::vector<QString>>();

    srand (time(NULL));
    std::vector<QString> t_row;
    for (int i = 0; i < rows; i++) {
        t_row.clear();
        for (int j = 0; j < columns; j++) {
            t_row.push_back( colors[rand() % colors.size()] );
        }
        gameMatrix.push_back(std::move(t_row));
    }
}

SameGame::SameGame(int rows, int columns)
    : colors(settings->value("colors/colors", QList<QVariant>() << "#A90A5A" << "#FFD1D9" << "#DB7093" << "#F7A8B8" << "#660033").toStringList())
{
    initialiseGameMatrix(rows, columns);
}

QString SameGame::getCell(int row, int column) {
    return gameMatrix[row][column];
}

void SameGame::setCell(int row, int column, QString color) {
    gameMatrix[row][column] = color;
}

void SameGame::checkNeighbour(std::set<std::vector<int>> *connectedSet, QString color, int row, int column) {
    if (row > -1 && column > -1 && (unsigned long) row < gameMatrix.size() && (unsigned long) column < gameMatrix[0].size()) {
        if ( !(connectedSet->contains(std::vector<int>{row, column})) ) {
            if (gameMatrix[row][column] == color)
                getConnected(connectedSet, color, row, column);
        }
    }
}

void SameGame::deleteCell(int row, int column) {
    gameMatrix[row][column] = "none";
}

void SameGame::getConnected(std::set<std::vector<int>> *connectedSet, QString color, int row, int column) {
    std::vector<int> cellCoords;
    cellCoords.push_back(row);
    cellCoords.push_back(column);
    connectedSet->insert(cellCoords);
    checkNeighbour(connectedSet, color, row+1, column);
    checkNeighbour(connectedSet, color, row-1, column);
    checkNeighbour(connectedSet, color, row, column+1);
    checkNeighbour(connectedSet, color, row, column-1);
}

int SameGame::getNumberOfColors() {
    return colors.size();
}
