/*!
 * \file settings.hpp
 * \brief Includes the external #settings `unique_ptr`.
 */

#ifndef SETTINGS_HPP
#define SETTINGS_HPP

#include <QSettings>

/*!
 * \defgroup Settings Settings
 * \brief Configuration of your SameGame.
 * \details If you wish to just see the documentation of using the configuration file, go to \ref ini_config. \n
 * The implementation of it is documented in \ref Settings_src.
 */

/*!
 * \example ThinkPink.ini
 * Default configuration file.
 */

/*!
 * \defgroup ini_config Configuration
 * \ingroup Settings
 * \brief Quick explanation of using the `ThinkPink.ini` configuration file for customising your \ref ThinkPink experience.
 * \section Keys
 * \subsection Size
 * To adjust the size of the game grid, change the keys `columns` and `rows` to the desired integer values.
 * \subsection Colors
 * A list of all colors that can get picked for the initial game grid. You can edit the list to have as many or as few colors as you want, using the hexadecimal color values.
 * \section Default Default configuration file
 * \verbinclude{doc} ThinkPink.ini
 * \todo document config file location
 */

/*!
 * \defgroup Settings_src C++ Implementation
 * \ingroup Settings
 * \brief Overview of all sources that initialise and declare the `std::unique_ptr<QSettings>` #settings.
 * \details Initialising the QSettings using a std::unique_ptr enables usage of user configuration at load time. \n
 * This means that we can have the grid size of \ref SameGame::gameMatrix and color list \ref SameGame::colors as constants. \n
 * To see the settings stored and loaded in #settings, see \sa ini_config the Configuration documentation for the `ThinkPink.ini`.
 */

/*!
 * \brief global `unique_ptr` of #QSettings \n
 * Granting global access to #QSettings at load time.
 * \ingroup Settings_src
 */
extern std::unique_ptr<QSettings> settings;

#endif // SETTINGS_HPP
